@@ -1,3 +1,8 @@
+from cors import preflight
+
+def not_allowed():
+    return "", 405
+
 class Endpoint:
     http_verbs = ["get", "head", "post", "put", "delete", "connect", "options",
                   "trace", "patch"]
@@ -11,9 +16,12 @@ class Endpoint:
     @classmethod
     def handle(cls, method):
         method = method.lower()
-        methods = ([f for f in dir(cls) if f in cls.http_verbs])
 
+        if method == "options":
+            return preflight
+
+        methods = ([f for f in dir(cls) if f in cls.http_verbs])
         if method not in methods:
-            print("405", "method not allowed")
+            return not_allowed
 
         return getattr(cls, method)
